Package: TFutils
Title: TFutils
Description: This package helps users to work with TF metadata from various sources.
	Significant catalogs of TFs and classifications thereof are made available.
	Tools for working with motif scans are also provided.
Version: 1.32.0
Authors@R: c(
 person("Vincent", "Carey", role = c("aut", "cre"), email = "stvjc@channing.harvard.edu"),
 person("Shweta", "Gopaulakrishnan", role = c("aut"), email = "reshg@channing.harvard.edu"))
Depends: R (>= 4.1.0)
Imports: methods, dplyr, magrittr, miniUI, shiny, Rsamtools, GSEABase,
        rjson, BiocFileCache, DT, httr, readxl, AnnotationDbi,
        org.Hs.eg.db, utils, GenomicFiles, SummarizedExperiment
Suggests: knitr, data.table, testthat, AnnotationFilter, Biobase,
        GenomicFeatures, GenomicRanges, Gviz, IRanges, S4Vectors,
        EnsDb.Hsapiens.v75, BiocParallel, BiocStyle, GO.db, Seqinfo,
        UpSetR, ggplot2, png, gwascat, MotifDb, motifStack,
        RColorBrewer, rmarkdown
License: Artistic-2.0
LazyLoad: true
ByteCompile: true
LazyData: true
VignetteBuilder: knitr
RoxygenNote: 7.3.2
biocViews: Transcriptomics
Roxygen: list(markdown = TRUE)
Encoding: UTF-8
git_url: https://git.bioconductor.org/packages/TFutils
git_branch: RELEASE_3_23
git_last_commit: ac50301
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 01:10:46 UTC; biocbuild
Author: Vincent Carey [aut, cre],
  Shweta Gopaulakrishnan [aut]
Maintainer: Vincent Carey <stvjc@channing.harvard.edu>
