# Generated by roxygen2: do not edit by hand

export(HGNCmap)
export(TFCatalog)
export(TFtargs)
export(URL_s3_tf)
export(anchor_pmids)
export(browse_gotf_main)
export(browse_humantfs_main)
export(browse_lambert_gwaslinks)
export(browse_lambert_main)
export(defaultCircosParms)
export(directHitsInCISBP)
export(fimo_granges)
export(genemodForGviz)
export(genemodelDF)
export(get_rslocs_38)
export(grabTab)
export(importFIMO_local_split)
export(retrieve_gotf_main)
export(retrieve_humantfs_main)
export(retrieve_lambert_main)
export(tffamCirc.plot)
export(tffamCirc.prep)
export(topTraitsOfTargets)
exportClasses(TFCatalog)
exportMethods(importFIMO)
exportMethods(show)
import(AnnotationDbi, except=select)
import(BiocFileCache)
import(SummarizedExperiment)
import(dplyr)
import(magrittr)
import(miniUI)
import(org.Hs.eg.db)
import(readxl)
importClassesFrom(GSEABase,GeneSetCollection)
importClassesFrom(Rsamtools,TabixFile)
importFrom(GSEABase,SymbolIdentifier)
importFrom(GSEABase,geneIdType)
importFrom(GSEABase,geneIds)
importFrom(GSEABase,mapIdentifiers)
importFrom(GenomicFiles,reduceByRange)
importFrom(Rsamtools,scanTabix)
importFrom(methods,as)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,show)
importFrom(methods,slot)
importFrom(shiny,dataTableOutput)
importFrom(shiny,observeEvent)
importFrom(shiny,reactive)
importFrom(shiny,renderDataTable)
importFrom(shiny,runGadget)
importFrom(shiny,selectInput)
importFrom(shiny,stopApp)
importFrom(stats,family)
importFrom(stats,na.omit)
importFrom(utils,read.csv)
importFrom(utils,read.csv2)
importFrom(utils,read.delim)
