THE SOURCE IS IN vignettes/TFutils, generated by "draft"!!

rmarkdown::draft(file = "TFutils.Rmd", 
                 template = "f1000_article", 
                 package = "BiocWorkflowTools", 
                 edit = FALSE)

