% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/go_tf_get.R
\name{gotf_url}
\alias{gotf_url}
\title{Update Oct 18 2021}
\usage{
gotf_url()
}
\description{
Update Oct 18 2021
}
