% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lambert_ccbr_get.R
\name{ccbr_cell_url}
\alias{ccbr_cell_url}
\title{Update Oct 18 2021}
\usage{
ccbr_cell_url()
}
\description{
Update Oct 18 2021
}
